API Reference
=============

Submodules
----------

.. toctree::
   :titlesonly:

   /api/jsonschema/validators/index
   /api/jsonschema/exceptions/index
   /api/jsonschema/protocols/index

:mod:`jsonschema`
-----------------

.. automodule:: jsonschema
   :members:
   :imported-members:
   :exclude-members: Validator

.. autodata:: jsonschema._format._F

.. autodata:: jsonschema._typing.id_of
